@@ -20,12 +20,12 @@
  * @author Sam Lang, Sam Meder
  * 
  * $RCSfile: accept_delegation.c,v $
- * $Revision: 1.38 $
- * $Date: 2009/02/25 14:51:01 $
+ * $Revision: 1.38.42.1 $
+ * $Date: 2012/05/07 18:38:53 $
  */
 #endif
 
-static char *rcsid = "$Id: accept_delegation.c,v 1.38 2009/02/25 14:51:01 bester Exp $";
+static char *rcsid = "$Id: accept_delegation.c,v 1.38.42.1 2012/05/07 18:38:53 bester Exp $";
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
@@ -103,7 +103,7 @@ GSS_CALLCONV gss_accept_delegation(
     BIO *                               bio = NULL;
     BIO *                               read_bio = NULL;
     BIO *                               write_bio = NULL;
-    X509 *                              peer_cert;
+    X509 *                              peer_cert = NULL;
     const EVP_MD *                      peer_digest;
     OM_uint32                           major_status = GSS_S_COMPLETE;
     OM_uint32                           local_minor_status;
@@ -416,6 +416,11 @@ GSS_CALLCONV gss_accept_delegation(
     }
     
  mutex_unlock:
+    if (peer_cert)
+    {
+        X509_free(peer_cert);
+    }
+    
     globus_mutex_unlock(&context->mutex);
 
  exit:
