@@ -21,12 +21,12 @@
  * @author Sam Meder, Sam Lang
  *
  * $RCSfile: accept_sec_context.c,v $
- * $Revision: 1.36 $
- * $Date: 2011/11/02 13:47:22 $
+ * $Revision: 1.36.2.1 $
+ * $Date: 2013/10/10 15:22:00 $
  */
 #endif
 
-static char * rcsid = "$Id: accept_sec_context.c,v 1.36 2011/11/02 13:47:22 bester Exp $";
+static char * rcsid = "$Id: accept_sec_context.c,v 1.36.2.1 2013/10/10 15:22:00 bester Exp $";
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
@@ -79,7 +79,7 @@ GSS_CALLCONV gss_accept_sec_context(
     STACK_OF(X509) *                    cert_chain = NULL;
     globus_gsi_cert_utils_cert_type_t   cert_type;
     int                                 readlen;
-    X509 *                              peer_cert;
+    X509 *                              peer_cert = NULL;
     const EVP_MD *                      peer_digest;
 
     static char *                       _function_name_ =
@@ -627,6 +627,10 @@ GSS_CALLCONV gss_accept_sec_context(
             (unsigned int) context->ret_flags));
 
  exit:
+    if (peer_cert != NULL)
+    {
+        X509_free(peer_cert);
+    }
 
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
